#!/usr/bin/env python

##############################################################################
##
## Copyright (C) 2021 Narda Safety Test Solutions GmbH.
## Contact: www.narda-sts.com
##
## Redistribution and use in source and binary forms,
## with or without modification, are permitted provided that the following
## conditions are met:
##
## 1.) Redistributions of source code must retain the above copyright notice,
## this list of conditions and the following disclaimer.
##
## 2.) Redistributions in binary form must reproduce the above copyright
## notice, this list of conditions and the following disclaimer in the
## documentation and/or other materials provided with the distribution.
##
## 3.) Neither the name of the copyright holder nor the names of its
## contributors may be used to endorse or promote products derived from this
## software without specific prior written permission.
##
## 4.) EXPORT CONTROL
## The Software, including technical data /cryptographic software,
## may be subject to, German, European Union and U.S. export controls and
## may be subject to import or export controls in other countries.
## The Licensee agrees to strictly comply with all applicable import and
## export regulations. He specifically agrees, that he must not disclose or
## otherwise export or re-export the Licensed Software or any part thereof
## delivered under this end user license agreement (EULA) to any country
## (including a national or resident of such country) without a valid export
## or import license. Please be aware that the Software may contain
## US-Content, therefor the Licensee represent and warrant that he is not a
## citizen of, or otherwise located within, an embargoed nation (including
## without limitation Iran, Syria, Sudan, Cuba, North Korea) and that he is
## not otherwise prohibited under the Export Laws from receiving the Software.
## All rights to Use the Software are granted on condition that such rights
## are forfeited if the Licensee fails to comply with
## the terms of this Agreement.
##
## 5.) SEVERABILITY
## Should any provision of this Agreement be or become invalid, ineffective
## or unenforceable, the remaining provisions of this Agreement shall be
## valid. The parties agree to replace the invalid, ineffective or
## unenforceable provision by a valid, effective and enforceable provision
## which best meets the commercial intention of the parties.
## The same shall apply in case of omissions.
##
## 6.) APPLICABLE LAW AND PLACE OF JURISTICATION
## This Agreement shall be constituted under the law of Germany.
## The United Nations Convention on the International Sale of Goods
## shall not apply to this Agreement. The Place of Jurisdiction for any
## dispute between the Parties shall be Tübingen (Germany).
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## “AS IS” AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
## TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
## PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL Narda Safety Test Solutions GmbH
## BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
## CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
## SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
## INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
## CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
## ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
##
##############################################################################



import wx
from nardascripting.base.signalsharkdev import *
from nardascripting.base.usrscriptbase import *
from .gnssdialogsbase import GnssSettingsBaseDlg, GnssInfoBaseDlg
from nardascripting.base.measthread import *


class GnssSettingsDlg(GnssSettingsBaseDlg):
    """Settings dialog"""

    def __init__(self, parent, msg: str):
        """Initialization"""
        super().__init__(parent)

    def on_cancel(self, event):
        event.Skip()

    def on_ok(self, event):
        event.Skip()


class GnssInfoDlg(GnssInfoBaseDlg):
    def __init__(self, parent):
        super().__init__(parent)
        self.init_progress_bar(self.pgb_progress)
        self.init_dlg_buttons(self.sdbs_buttons, wx.OK)
        self.btn_ok.SetLabel("Quit")
        self._actual_warning = False

    def update_progress(self, evt: ProgressEvent):
        """Receives data from thread and updates progressbar and message text

        :param evt: Event of type ProgressEvent.
        """

        # Handle progress
        self.update_progress_bar(evt, self.pgb_progress)

        # Handle message
        if evt.msg is not None:
            self.lbl_status.SetLabelText(evt.msg)

        # Handle data:
        if evt.data is not None:
            self.__update_info(evt.data)

        # Handle buttons:
        if evt.btn_style:
            self.update_btn_style(evt.btn_style)

        # Handle icons:
        if evt.icon_style:
            self.update_icon_style(self.bmp_icon, evt.icon_style)

        # Handle help text:
        if evt.help_text:
            self.help_text = evt.help_text

        self.Layout()
        self.Refresh()
        self.Update()

    def __update_info(self, gnss_data: GnssDataRaw):
        """ Updates the GNSS information fields
        :param gnss_data: GNSS data
        :return:
        """
        if gnss_data is None:
            return

        self.txt_time_of_last_telegram.SetLabelText(str(gnss_data.last_telegram_timestamp))
        self.txt_time_of_last_posfix.SetLabelText(str(gnss_data.last_pos_fix_timestamp))
        self.txt_quality.SetLabelText(str(gnss_data.quality))
        self.txt_fix.SetLabelText(str(gnss_data.fix))
        self.txt_no_of_satellites.SetLabelText(str(gnss_data.satellites))
        self.txt_latitude.SetLabelText(str(gnss_data.latitude))
        self.txt_longitude.SetLabelText(str(gnss_data.longitude))
        self.txt_altitude.SetLabelText(str(gnss_data.altitude))
        self.txt_speed.SetLabelText(str(gnss_data.speed))
        self.txt_course.SetLabelText(str(gnss_data.course))

        # Quality Trigger Indication and Panel Color Change
        if gnss_data.quality == GnssQuality.FROZEN or gnss_data.quality == GnssQuality.NOFIX:
            if not self._actual_warning:
                self.m_panel21.SetBackgroundColour((255, 0, 0))
                self.lbl_status.SetLabelText("Quality Alert Raised.")
                self._actual_warning = True
        else:
            if self._actual_warning:
                self.m_panel21.SetBackgroundColour((255, 255, 255))
                self.lbl_status.SetLabelText("No Quality Issues.")
                self._actual_warning = False


# This is just a python module containing helper classes/functions:
if __name__ == '__main__':
    pass
